*********************
``matplotlib.pyplot``
*********************

Pyplot function overview
------------------------

.. currentmodule:: matplotlib

.. autosummary::
   :toctree: _as_gen
   :template: autofunctions.rst

   pyplot

.. currentmodule:: matplotlib.pyplot

.. autofunction:: plotting


Colors in Matplotlib
--------------------

There are many colormaps you can use to map data onto color values.
Below we list several ways in which color can be utilized in Matplotlib.

For a more in-depth look at colormaps, see the
:doc:`/tutorials/colors/colormaps` tutorial.

.. currentmodule:: matplotlib.pyplot

.. autofunction:: colormaps
